<?xml version="1.0" encoding="UTF-8"?>
<!--
 - Desc:    This file is part of the eCromedos document preparation system
 - Date:    2006/03/09
 - Author:  Tobias Koch (tkoch@ecromedos.net)
 - License: GNU General Public License, version 2
 - URL:     http://www.ecromedos.net
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- activates fixes for prevailing latex bugs -->
<xsl:param name="colortblfix" select="'no'"/>
<xsl:param name="multicolumnfix" select="'no'"/>
<xsl:param name="pagebreakfix" select="'yes'"/>

<!--
  - Column mode
-->
<xsl:param name="global.columns">
	<xsl:choose>
		<xsl:when test="/*[1]/@columns">
			<xsl:value-of select="/*[1]/@columns"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:number select="1"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:param>

<!--
  - Generate preamble and initialize counters
-->
<xsl:template name="latex.prepare">
	<xsl:call-template name="latex.documentclass"/>
	<xsl:call-template name="latex.preamble"/>
	<xsl:call-template name="latex.babel.load"/>

	<xsl:variable name="tocdepth">
		<xsl:call-template name="util.tocdepth"/>
	</xsl:variable>
	<xsl:variable name="secnumdepth">
		<xsl:call-template name="util.secnumdepth"/>
	</xsl:variable>
	
	<!-- set depth of section numbering -->
	<xsl:text>\setcounter{secnumdepth}{</xsl:text>
		<xsl:choose>
			<xsl:when test="/book or /report">
				<xsl:value-of select="$secnumdepth - 1"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$secnumdepth"/>
			</xsl:otherwise>
		</xsl:choose>
	<xsl:text>}&#x0a;&#x0a;</xsl:text>
	<!-- set depth of toc listing -->
	<xsl:text>\setcounter{tocdepth}{</xsl:text>
		<xsl:choose>
			<xsl:when test="/book or /report">
				<xsl:value-of select="$tocdepth - 1"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$tocdepth"/>
			</xsl:otherwise>
		</xsl:choose>
	<xsl:text>}&#x0a;&#x0a;</xsl:text>
</xsl:template>

<!--
  - Select LaTeX document class
-->
<xsl:template name="latex.documentclass">
	<xsl:text>\documentclass[</xsl:text>
	<xsl:choose>
		<xsl:when test="@fontsize">
			<xsl:value-of select="@fontsize"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>11pt</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>,</xsl:text>
	<xsl:choose>
		<xsl:when test="@papersize">
			<xsl:value-of select="@papersize"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>a4paper</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:choose>
		<xsl:when test="@columns = 2">
			<xsl:text>,twocolumn</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:choose>
		<xsl:when test="/book">
			<xsl:text>,cleardoubleempty,pagesize,headsepline</xsl:text>
			<xsl:text>,headinclude,footexclude]{scrbook}&#x0a;&#x0a;</xsl:text>
		</xsl:when>
		<xsl:when test="/article">
			<xsl:text>,pagesize,abstracton</xsl:text>
			<xsl:text>,headinclude,footexclude]{scrartcl}&#x0a;&#x0a;</xsl:text>
		</xsl:when>
		<xsl:when test="/report">
			<xsl:text>,pagesize</xsl:text>
			<xsl:text>,headinclude,footexclude]{scrreprt}&#x0a;&#x0a;</xsl:text>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!--
  - Generate LaTeX document preamble
-->
<xsl:template name="latex.preamble">

	<xsl:text>% Make LaTeX unicode-aware&#x0a;</xsl:text>
	<xsl:text>\usepackage[postscript]{ucs}&#x0a;</xsl:text>
	<xsl:text>\usepackage[utf8x]{inputenc}&#x0a;</xsl:text>
	<xsl:text>\usepackage[T1]{autofe}&#x0a;&#x0a;</xsl:text>

	<xsl:text>% Use postscript fonts&#x0a;</xsl:text>
	<xsl:text>\usepackage{pifont}&#x0a;</xsl:text>
	<xsl:text>\usepackage{textcomp}&#x0a;</xsl:text>
	<xsl:text>\usepackage{courier}&#x0a;</xsl:text>
	<xsl:text>\usepackage{helvet}&#x0a;</xsl:text>
	<xsl:text>\usepackage{mathptmx}&#x0a;</xsl:text>
	<xsl:text>\PrerenderUnicode{äöüß–}&#x0a;&#x0a;</xsl:text>

	<xsl:text>% Make euro symbol available&#x0a;</xsl:text>
	<xsl:text>\usepackage[gen]{eurosym}&#x0a;&#x0a;</xsl:text>

	<xsl:text>% Load math environment&#x0a;</xsl:text>
	<xsl:text>\usepackage{amsmath}&#x0a;</xsl:text>
	<xsl:text>\usepackage{amsthm}&#x0a;&#x0a;</xsl:text>

	<xsl:text>% Disable extra space after full-stops&#x0a;</xsl:text>
	<xsl:text>\frenchspacing{}&#x0a;&#x0a;</xsl:text>

	<xsl:text>% Set scientific style, i.e. no paragraph indentation&#x0a;</xsl:text>
	<xsl:text>\setlength{\parindent}{0em}&#x0a;</xsl:text>
	<xsl:text>\setlength{\parskip}{1ex plus 0.5ex minus 0.2ex}&#x0a;&#x0a;</xsl:text>

	<xsl:text>\usepackage{here}&#x0a;</xsl:text>
	<xsl:text>\usepackage{flafter}&#x0a;&#x0a;</xsl:text>

	<xsl:text>% Table stuff&#x0a;</xsl:text>
	<xsl:text>\usepackage{ltabptch}&#x0a;</xsl:text>
	<xsl:text>\setlength{\partopsep}{0ex}&#x0a;</xsl:text>
	<xsl:text>\setlength{\topsep}{1ex}&#x0a;</xsl:text>
	<xsl:text>\usepackage{hhline}&#x0a;</xsl:text>
	<xsl:text>\usepackage{array}&#x0a;</xsl:text>
	<xsl:text>\usepackage{calc}&#x0a;</xsl:text>
	<xsl:text>\newlength{\ecmdstablewidth}&#x0a;</xsl:text>
	<xsl:text>\newlength{\ecmdscolsep}&#x0a;</xsl:text>

	<xsl:text>% Color and verbatim environment&#x0a;</xsl:text>
	<xsl:text>\usepackage{color}&#x0a;</xsl:text>
	<xsl:text>\usepackage{framed}&#x0a;</xsl:text>
	<xsl:text>\usepackage{colortbl}&#x0a;</xsl:text>
	<xsl:text>\doublerulesepcolor{white}&#x0a;</xsl:text>
	<xsl:text>\usepackage{alltt}&#x0a;</xsl:text>
	<xsl:text>\newcommand{\rgbshadecolor}[3]{\definecolor{shadecolor}{rgb}{#1,#2,#3}}&#x0a;</xsl:text>
	<xsl:text>\newcommand{\rgbcolor}[4]{\textcolor[rgb]{#1,#2,#3}{#4}}&#x0a;&#x0a;</xsl:text>

	<xsl:if test="$colortblfix = 'yes'">
		<xsl:text>% some colortbl.stys cause problems with doubleruleseps in longtable&#x0a;</xsl:text>
		<xsl:text>\makeatletter&#x0a;</xsl:text>
		<xsl:text>\AtBeginDocument{&#x0a;</xsl:text>
		<xsl:text>  \ifx\longtable\@undefined\else&#x0a;</xsl:text>
		<xsl:text>    \def\LT@@hline{%&#x0a;</xsl:text>
		<xsl:text>      \ifx\@let@token\hline&#x0a;</xsl:text>
		<xsl:text>        \global\let\@let@token\@gobble&#x0a;</xsl:text>
		<xsl:text>        \ifx\CT@drsc@\relax&#x0a;</xsl:text>
		<xsl:text>          \gdef\CT@LT@sep{%&#x0a;</xsl:text>
		<xsl:text>            \noalign{\penalty-\@medpenalty\vskip\doublerulesep}}%&#x0a;</xsl:text>
		<xsl:text>        \else&#x0a;</xsl:text>
		<xsl:text>          \gdef\CT@LT@sep{%&#x0a;</xsl:text>
		<xsl:text>            \multispan\LT@cols{%&#x0a;</xsl:text>
		<xsl:text>              \CT@drsc@\leaders\hrule\@height\doublerulesep\hfill}\cr}%&#x0a;</xsl:text>
		<xsl:text>        \fi&#x0a;</xsl:text>
		<xsl:text>      \else&#x0a;</xsl:text>
		<xsl:text>        \global\let\@let@token\@empty&#x0a;</xsl:text>
		<xsl:text>        \gdef\CT@LT@sep{%&#x0a;</xsl:text>
		<xsl:text>          \noalign{\penalty-\@lowpenalty\vskip-\arrayrulewidth}}%&#x0a;</xsl:text>
		<xsl:text>      \fi&#x0a;</xsl:text>
		<xsl:text>      \ifnum0=`{\fi}%&#x0a;</xsl:text>
		<xsl:text>      \multispan\LT@cols&#x0a;</xsl:text>
		<xsl:text>      {\CT@arc@\leaders\hrule\@height\arrayrulewidth\hfill}\cr&#x0a;</xsl:text>
		<xsl:text>      \CT@LT@sep&#x0a;</xsl:text>
		<xsl:text>      \multispan\LT@cols&#x0a;</xsl:text>
		<xsl:text>      {\CT@arc@\leaders\hrule\@height\arrayrulewidth\hfill}\cr&#x0a;</xsl:text>
		<xsl:text>      \noalign{\penalty\@M}%&#x0a;</xsl:text>
		<xsl:text>      \@let@token}&#x0a;</xsl:text>
		<xsl:text>    \fi}&#x0a;</xsl:text>
		<xsl:text>\makeatother&#x0a;&#x0a;</xsl:text>
	</xsl:if>

	<xsl:if test="$pagebreakfix = 'yes'">
		<xsl:text>\makeatletter&#x0a;</xsl:text>
		<xsl:text>\typeout{fix for tools/2796}&#x0a;</xsl:text>
		<xsl:text>\def\LT@start{%&#x0a;</xsl:text>
		<xsl:text>  \let\LT@start\endgraf&#x0a;</xsl:text>
		<xsl:text>  \endgraf\penalty\z@\vskip\LTpre&#x0a;</xsl:text>
		<xsl:text>  \dimen@\pagetotal&#x0a;</xsl:text>
		<xsl:text>  \advance\dimen@ \ht\ifvoid\LT@firsthead\LT@head\else\LT@firsthead\fi&#x0a;</xsl:text>
		<xsl:text>  \advance\dimen@ \dp\ifvoid\LT@firsthead\LT@head\else\LT@firsthead\fi&#x0a;</xsl:text>
		<xsl:text>  \advance\dimen@ \ht\LT@foot&#x0a;</xsl:text>
		<xsl:text>  \dimen@ii\vfuzz&#x0a;</xsl:text>
		<xsl:text>  \vfuzz\maxdimen&#x0a;</xsl:text>
		<xsl:text>    \setbox\tw@\copy\z@&#x0a;</xsl:text>
		<xsl:text>    \setbox\tw@\vsplit\tw@ to \ht\@arstrutbox&#x0a;</xsl:text>
		<xsl:text>    \setbox\tw@\vbox{\unvbox\tw@}%&#x0a;</xsl:text>
		<xsl:text>  \vfuzz\dimen@ii&#x0a;</xsl:text>
		<xsl:text>  \advance\dimen@ \ht&#x0a;</xsl:text>
		<xsl:text>        \ifdim\ht\@arstrutbox>\ht\tw@\@arstrutbox\else\tw@\fi&#x0a;</xsl:text>
		<xsl:text>  \advance\dimen@\dp&#x0a;</xsl:text>
		<xsl:text>        \ifdim\dp\@arstrutbox>\dp\tw@\@arstrutbox\else\tw@\fi&#x0a;</xsl:text>
		<xsl:text>  \advance\dimen@ -\pagegoal&#x0a;</xsl:text>
		<xsl:text>%  \ifdim \dimen@>\z@\vfil\break\fi&#x0a;</xsl:text>
		<xsl:text>  \ifdim \dimen@>\z@\unskip\vfil\break\fi&#x0a;</xsl:text>
		<xsl:text>      \global\@colroom\@colht&#x0a;</xsl:text>
		<xsl:text>  \ifvoid\LT@foot\else&#x0a;</xsl:text>
		<xsl:text>    \advance\vsize-\ht\LT@foot&#x0a;</xsl:text>
		<xsl:text>    \global\advance\@colroom-\ht\LT@foot&#x0a;</xsl:text>
		<xsl:text>    \dimen@\pagegoal\advance\dimen@-\ht\LT@foot\pagegoal\dimen@&#x0a;</xsl:text>
		<xsl:text>    \maxdepth\z@&#x0a;</xsl:text>
		<xsl:text>  \fi&#x0a;</xsl:text>
		<xsl:text>  \ifvoid\LT@firsthead\copy\LT@head\else\box\LT@firsthead\fi&#x0a;</xsl:text>
		<xsl:text>  \output{\LT@output}}&#x0a;</xsl:text>
		<xsl:text>\makeatother&#x0a;&#x0a;</xsl:text>
	</xsl:if>

	<xsl:if test="$multicolumnfix = 'yes'">
		<xsl:text>% in some versions multicolumn does not accept multiple paragraphs&#x0a;</xsl:text>
		<xsl:text>\expandafter\renewcommand\expandafter\multicolumn&#x0a;</xsl:text>
		<xsl:text>  \expandafter[\expandafter3\expandafter]\expandafter{%&#x0a;</xsl:text>
		<xsl:text>    \multicolumn{#1}{#2}{#3}}&#x0a;&#x0a;</xsl:text>
	</xsl:if>

	<xsl:text>% Redefine paragraph&#x0a;</xsl:text>
	<xsl:text>\makeatletter&#x0a;</xsl:text>
	<xsl:text>\renewcommand{\paragraph}{\@startsection{paragraph}{4}{\z@}%&#x0a;</xsl:text>
	<xsl:text>    {-0ex\@plus -0.5ex \@minus -.2ex}%&#x0a;</xsl:text>
	<xsl:text>    {-1.5ex}%&#x0a;</xsl:text>
	<xsl:text>    {\normalfont\normalsize\bfseries}}&#x0a;</xsl:text>
	<xsl:text>\makeatother&#x0a;&#x0a;</xsl:text>
	
	<xsl:text>% Disable auto-hyphenation of underlined text&#x0a;</xsl:text>
	<xsl:text>\usepackage[normalem]{ulem}&#x0a;&#x0a;</xsl:text>

	<xsl:text>% Graphics environment&#x0a;</xsl:text>
	<xsl:text>\usepackage[dvipdf,dvipdfm,dvips]{graphicx}&#x0a;&#x0a;</xsl:text>
	
	<xsl:text>% Captions&#x0a;</xsl:text>
	<xsl:text>\usepackage[format=hang,position=below,labelsep=colon,tableposition=top,labelfont=bf]{caption}&#x0a;&#x0a;</xsl:text>
	
	<xsl:text>% Inline objects&#x0a;</xsl:text>
	<xsl:text>\usepackage{wrapfig}&#x0a;&#x0a;</xsl:text>

	<xsl:text>% Enable custom page headers&#x0a;</xsl:text>
	<xsl:text>\usepackage{scrpage2}&#x0a;</xsl:text>
	<xsl:text>\clearscrheadfoot&#x0a;</xsl:text>
	
	<xsl:choose>
		<xsl:when test="/book">
			<xsl:text>\ohead{\pagemark}&#x0a;</xsl:text>
			<xsl:text>\ihead{\headmark}&#x0a;&#x0a;</xsl:text>
		</xsl:when>
		<xsl:when test="/report">
			<xsl:text>\automark{chapter}&#x0a;</xsl:text>
			<xsl:text>\chead{\headmark}&#x0a;</xsl:text>
			<xsl:text>\cfoot{\pagemark}&#x0a;</xsl:text>
			<xsl:text>\deftripstyle{stylechapter}{}{}{}{}{\pagemark}{}&#x0a;</xsl:text>
			<xsl:text>\renewcommand*{\chapterpagestyle}{stylechapter}&#x0a;&#x0a;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\automark{section}&#x0a;</xsl:text>
			<xsl:text>\chead{\headmark}&#x0a;</xsl:text>
			<xsl:text>\cfoot{\pagemark}&#x0a;&#x0a;</xsl:text>
		</xsl:otherwise>
	</xsl:choose>

	<xsl:text>% Recalculate layout&#x0a;</xsl:text>
	<xsl:text>\typearea[</xsl:text>
	<xsl:choose>
		<xsl:when test="@bcor">
			<xsl:value-of select="@bcor"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>0mm</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>]{</xsl:text>
	<xsl:choose>
		<xsl:when test="@div">
			<xsl:value-of select="@div"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>calc</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}&#x0a;&#x0a;</xsl:text>

</xsl:template>

<!--
  - Load babel
-->
<xsl:template name="latex.babel.load">
	<!-- load babel languages -->
	<xsl:text>% Select babel language&#x0a;</xsl:text>
	<xsl:text>\usepackage[</xsl:text>
	<xsl:choose>
		<xsl:when test="//@lang">
			<xsl:for-each select="//@lang">
				<xsl:if test="position() > 1">
					<xsl:text>,</xsl:text>
				</xsl:if>
				<xsl:value-of select="."/>
			</xsl:for-each>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>german</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>]{babel}&#x0a;&#x0a;</xsl:text>
</xsl:template>

<!--
  - Load hyphenation patterns and automatic titles for language
-->
<xsl:template name="latex.babel.select">
	<!-- select babel language -->
	<xsl:text>\selectlanguage{</xsl:text>
	<xsl:choose>
		<xsl:when test="/*[1]/@lang">
			<xsl:value-of select="/*[1]/@lang"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>german</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}&#x0a;&#x0a;</xsl:text>
</xsl:template>

</xsl:stylesheet>
